mean_cov_score — skchange

Skip to main content
`Ctrl`+`K`

# mean_cov_score

mean_cov_score(precomputed_params: ndarray, starts: ndarray, ends: ndarray, splits: ndarray) → ndarray

  Calculate likelihood ratio scores for a change in mean and covariance [1].

  Parameters:
    precomputed_paramsTuple[np.ndarray, np.ndarray, np.ndarray]

      Precomputed parameters from init_covariance_score.

    startsnp.ndarray

      Start indices of the intervals to test for a change in the covariance.

    endsnp.ndarray

      End indices of the intervals to test for a change in the covariance.

    splitsnp.ndarray

      Split indices of the intervals to test for a change in the covariance.

  Returns:
    scoresnp.ndarray

      Scores for each start, end, split combination.

  References

  [1]

  Zamba, K. D., & Hawkins, D. M. (2009). A Multivariate Change-Point Model for Change in Mean Vector and/or Covariance Structure. Journal of Quality Technology, 41(3), 285-303.